@@ -172,9 +172,18 @@
 #endif
 
 #ifdef SCO
+#ifdef SCO3
+typedef	int	ssize_t;
+extern void closelog(void);
+#define ftruncate	chsize
+#define SA_RESTART	0
+#define SOMAXCONN 5
+#define NO_UNIX_SOCKET
+#else
 #define HAVE_GETRUSAGE
 #define HAVE_SNPRINTF
 #define HAVE_VSNPRINTF
+#endif
 #define SOCKLEN_T	int
 #define O_RSYNC		0
 #define PATH_TMP        "/tmp"
