@@ -48,7 +48,7 @@ static void open_seedfile(const char *seedfile)
    * The contents of the seedfile may be sensitive, since we start seeding
    * from the file.
    */
-  if (fchmod(randsavefd, S_IRUSR | S_IWUSR) < 0)
+  if (chmod(seedfile, S_IRUSR | S_IWUSR) < 0)
   {
     (void)snprintf(msg_buf, sizeof(msg_buf),
 	"Could not chmod %s: %s\n", seedfile, strerror(errno));
@@ -133,6 +133,7 @@ static void write_seedfile(void)
   }
   if (debug)
     (void)fprintf(stderr, "Wrote %d bytes back to seedfile\n", bytes);
+
   bytes = ftruncate(randsavefd, bytes);
 }
 
@@ -256,6 +257,7 @@ int main(int argc, char *argv[])
       seedpath = NULL;
     else if (!strcmp(argv[argp], "-k") || !strcmp(argv[argp], "--kill"))
       killmode = 1;
+#ifndef NO_UNIX_SOCKET
     else if (argv[argp][0] == '/') {
       if (numsock_file == 0)
         randsock_file = malloc(sizeof(char *));
@@ -268,6 +270,7 @@ int main(int argc, char *argv[])
       }
       randsock_file[numsock_file++] = argv[argp];
     }
+#endif /* NO_UNIX_SOCKET */
     else if (!strncmp(argv[argp], "tcp/localhost:", strlen("tcp/localhost:"))) {
       if (numsock_tcp == 0)
         randsock_tcp = malloc(sizeof(char *));
@@ -420,7 +423,7 @@ int main(int argc, char *argv[])
      * Check out what is already available at the place of the future
      * egd-socket. If we cannot reach the place to be with "stat()",
      * do not continue, as something may be seriously wrong. If the
-     * entry does already exist, remove() it, but only if it is of type
+     * entry does already exist, remove it, but only if it is of type
      * socket! If removal fails for whatever reason, stop, as something
      * may be seriously wrong.
      */
@@ -453,7 +456,7 @@ int main(int argc, char *argv[])
          * Now there is a socket without service listening on it: we can
 	 * remove it.
 	 */
-	if (remove(randsock_file[i]) < 0) {
+	if (unlink(randsock_file[i]) < 0) {
 	  (void)snprintf(msg_buf, sizeof(msg_buf),
 	  	"Cannot remove already existing entry %s", randsock_file[i]);
 	  msg_buf[sizeof(msg_buf) - 1] = '\0';
