@@ -7,7 +7,6 @@
 #include <signal.h>
 #include <time.h>
 #include <sys/stat.h>
-#include <sys/un.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -110,6 +109,7 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
   struct sigaction new_action;
   fd_set rfds, wfds, efds;
   struct timeval timeout;
+  int saved_errno;
 
   gatherer_pid = -1;
   gather_fd = -1;
@@ -171,7 +171,9 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
     if (gather_fd != -1)
     {
       FD_SET(gather_fd, &rfds);
+#ifndef SCO3
       FD_SET(gather_fd, &efds);
+#endif
       if (gather_fd > max_fd)
 	max_fd = gather_fd;
     }
@@ -204,6 +206,7 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
       timeout.tv_usec = 0;
     }
     num = select(max_fd + 1, &rfds, &wfds, &efds, &timeout);
+    saved_errno = errno;
 
     /*
      * Depending on the scheduling the SIGCHILD may already be old. This
@@ -232,8 +235,14 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
 
     seed_internal(NULL);
 
-    if (num < 0)
-      continue;		/* Ignore rfds and friends, since invalid */
+    if (num < 0) {
+      if (saved_errno == EINTR)
+        continue;		/* Ignore rfds and friends, since invalid */
+      else {
+	error_fatal("select() failed", saved_errno);
+	exit(EXIT_FAILURE);
+      }
+    }
 
     if (gather_fd != -1) {
       if (FD_ISSET(gather_fd, &efds)) {
